@@ -172,31 +172,15 @@ static void request_input_passphrase_reply(DBusPendingCall *call, void *user_dat
 		dbus_message_iter_next(&dict);
 	}
 
-	if (wps == TRUE) {
-		struct connman_network *network;
-
-		network = __connman_service_get_network(
-						passphrase_reply->service);
-		if (network == NULL)
-			goto done;
-
-		connman_network_set_bool(network, "WiFi.UseWPS", wps);
-
-		if (wpspin != NULL && strlen(wpspin) > 0)
-			connman_network_set_string(network,
-						"WiFi.PinWPS", wpspin);
-		else
-			connman_network_set_string(network,
-						"WiFi.PinWPS", NULL);
-	}
-
 done:
 	passphrase_reply->callback(passphrase_reply->service, values_received,
 				name, name_len,
 				identity, passphrase,
+				wps, wpspin,
 				passphrase_reply->user_data);
 	connman_service_unref(passphrase_reply->service);
 	dbus_message_unref(reply);
+	dbus_pending_call_unref(call);
 	g_free(passphrase_reply);
 }
 
@@ -371,6 +355,7 @@ done:
 	username_password_reply->callback(username_password_reply->service,
 					TRUE, NULL, 0,
 					username, password,
+					FALSE, NULL,
 					username_password_reply->user_data);
 	connman_service_unref(username_password_reply->service);
 	dbus_message_unref(reply);
