@@ -23,6 +23,7 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -45,7 +46,7 @@
 #define ARPHDR_PHONET_PIPE (821)
 #endif
 
-#define print(arg...) do { } while (0)
+#define print(arg...) do { if (0) connman_info(arg); } while (0)
 //#define print(arg...) connman_info(arg)
 
 struct watch_data {
@@ -109,7 +110,7 @@ static connman_bool_t wext_interface(char *ifname)
 	struct iwreq wrq;
 	int fd, err;
 
-	fd = socket(PF_INET, SOCK_DGRAM, 0);
+	fd = socket(PF_INET, SOCK_DGRAM | SOCK_CLOEXEC, 0);
 	if (fd < 0)
 		return FALSE;
 
@@ -600,6 +601,20 @@ static void process_newaddr(unsigned char family, unsigned char prefixlen,
 
 	__connman_ipconfig_newaddr(index, family, label,
 					prefixlen, ip_string);
+
+	if (family == AF_INET6) {
+		/*
+		 * Re-create RDNSS configured servers if there are any
+		 * for this interface. This is done because we might
+		 * have now properly configured interface with proper
+		 * autoconfigured address.
+		 */
+		char *interface = connman_inet_ifname(index);
+
+		__connman_resolver_redo_servers(interface);
+
+		g_free(interface);
+	}
 }
 
 static void process_deladdr(unsigned char family, unsigned char prefixlen,
@@ -1567,7 +1582,7 @@ int __connman_rtnl_init(void)
 	interface_list = g_hash_table_new_full(g_direct_hash, g_direct_equal,
 							NULL, free_interface);
 
-	sk = socket(PF_NETLINK, SOCK_DGRAM, NETLINK_ROUTE);
+	sk = socket(PF_NETLINK, SOCK_DGRAM | SOCK_CLOEXEC, NETLINK_ROUTE);
 	if (sk < 0)
 		return -1;
 
